summaryrefslogtreecommitdiffstats
path: root/mpeglib/lib/mpegplay
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 06:00:15 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 06:00:15 +0000
commitb1057f437bf65300831a0ccb45b920787c6b318d (patch)
treef8a73db06ca1180d0da0ba6dfbe786197b4f4bc3 /mpeglib/lib/mpegplay
parent4ddfca384ced9ad654213aef9dc2c3973720b980 (diff)
downloadtdemultimedia-b1057f437bf65300831a0ccb45b920787c6b318d.tar.gz
tdemultimedia-b1057f437bf65300831a0ccb45b920787c6b318d.zip
TQt4 port kdemultimedia
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdemultimedia@1236079 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'mpeglib/lib/mpegplay')
-rw-r--r--mpeglib/lib/mpegplay/decoderClass.cpp4
-rw-r--r--mpeglib/lib/mpegplay/jrevdct.h2
-rw-r--r--mpeglib/lib/mpegplay/macroBlock.cpp8
-rw-r--r--mpeglib/lib/mpegplay/mpegExtension.cpp6
-rw-r--r--mpeglib/lib/mpegplay/mpegExtension.h2
-rw-r--r--mpeglib/lib/mpegplay/mpegSystemStream.cpp2
-rw-r--r--mpeglib/lib/mpegplay/mpegVideoBitWindow.h4
-rw-r--r--mpeglib/lib/mpegplay/mpegVideoStream.cpp8
-rw-r--r--mpeglib/lib/mpegplay/pesSystemStream.cpp2
-rw-r--r--mpeglib/lib/mpegplay/picture.cpp2
-rw-r--r--mpeglib/lib/mpegplay/recon.cpp4
-rw-r--r--mpeglib/lib/mpegplay/slice.h2
-rw-r--r--mpeglib/lib/mpegplay/startCodes.h6
-rw-r--r--mpeglib/lib/mpegplay/videoDecoder.cpp14
-rw-r--r--mpeglib/lib/mpegplay/videoDecoder.h2
15 files changed, 34 insertions, 34 deletions
diff --git a/mpeglib/lib/mpegplay/decoderClass.cpp b/mpeglib/lib/mpegplay/decoderClass.cpp
index e259c8e6..0e46f752 100644
--- a/mpeglib/lib/mpegplay/decoderClass.cpp
+++ b/mpeglib/lib/mpegplay/decoderClass.cpp
@@ -54,7 +54,7 @@ static const int zigzag_direct_mmx[64] = {
-/* Bit masks used by bit i/o operations. */
+/* Bit tqmasks used by bit i/o operations. */
@@ -647,7 +647,7 @@ void DecoderClass::ParseReconBlock(int& n,int& mb_intra,
* flush_bitsX <--> flushed += X;
* next16bits &= bitMask[flushed];
*
- * I've streamlined the code a lot, so that we don't have to mask
+ * I've streamlined the code a lot, so that we don't have to tqmask
* out the low order bits and a few of the extra adds are removed.
* bsmith
*/
diff --git a/mpeglib/lib/mpegplay/jrevdct.h b/mpeglib/lib/mpegplay/jrevdct.h
index d280c2ce..24ab126f 100644
--- a/mpeglib/lib/mpegplay/jrevdct.h
+++ b/mpeglib/lib/mpegplay/jrevdct.h
@@ -24,7 +24,7 @@ extern "C" {
#ifndef XMD_H
typedef int INT32;
typedef short INT16;
-typedef char INT8;
+// typedef char INT8;
#endif
typedef unsigned int UINT32;
typedef unsigned short UINT16;
diff --git a/mpeglib/lib/mpegplay/macroBlock.cpp b/mpeglib/lib/mpegplay/macroBlock.cpp
index 2e35e551..730fdd62 100644
--- a/mpeglib/lib/mpegplay/macroBlock.cpp
+++ b/mpeglib/lib/mpegplay/macroBlock.cpp
@@ -329,7 +329,7 @@ int MacroBlock::reconstruct(int& recon_right_for,
int& mb_motion_forw,
int& mb_motion_back,
PictureArray* pictureArray) {
- int mask, i;
+ int tqmask, i;
int zero_block_flag;
int mb_row;
int mb_col;
@@ -364,11 +364,11 @@ int MacroBlock::reconstruct(int& recon_right_for,
copyFunctions->startNOFloatSection();
- for (mask = 32, i = 0; i < 6; mask >>= 1, i++) {
+ for (tqmask = 32, i = 0; i < 6; tqmask >>= 1, i++) {
/* If block exists... */
- if ((mb_intra) || (cbp & mask)) {
+ if ((mb_intra) || (cbp & tqmask)) {
zero_block_flag = 0;
//copyFunctions->endNOFloatSection();
decoderClass->ParseReconBlock(i,mb_intra,
@@ -1067,7 +1067,7 @@ void MacroBlock::ReconSkippedBlock(unsigned char* source,
if (width == 16) {
if ((!right_half) && (!down_half)) {
if (right & 0x1) {
- /* No alignment, use bye copy */
+ /* No tqalignment, use bye copy */
for (rr = 0; rr < 16; rr++) {
memcpy(dest,source,sizeof(char)*16);
diff --git a/mpeglib/lib/mpegplay/mpegExtension.h b/mpeglib/lib/mpegplay/mpegExtension.h
index 23b79c5b..3b0f1680 100644
--- a/mpeglib/lib/mpegplay/mpegExtension.h
+++ b/mpeglib/lib/mpegplay/mpegExtension.h
@@ -43,7 +43,7 @@ class MpegExtension {
private:
char* get_extra_bit_info(MpegVideoStream* mpegVideoStream);
- int next_bits(int num,unsigned int mask,MpegVideoStream* input);
+ int next_bits(int num,unsigned int tqmask,MpegVideoStream* input);
};
#endif
diff --git a/mpeglib/lib/mpegplay/mpegSystemStream.cpp b/mpeglib/lib/mpegplay/mpegSystemStream.cpp
index ca25d7e8..d4ec43a6 100644
--- a/mpeglib/lib/mpegplay/mpegSystemStream.cpp
+++ b/mpeglib/lib/mpegplay/mpegSystemStream.cpp
@@ -68,7 +68,7 @@ int MpegSystemStream::firstInitialize(MpegSystemHeader* mpegHeader) {
}
mpegHeader->setHeader(syncCode);
- // SEQ_START_CODE: 1b3
+ // SETQ_START_CODE: 1b3
if (mpegHeader->hasRAWHeader()) {
// If we found a seq_heade_start code we assume
// that we are a video only stream
diff --git a/mpeglib/lib/mpegplay/mpegVideoBitWindow.h b/mpeglib/lib/mpegplay/mpegVideoBitWindow.h
index 46abe44e..5c957e4d 100644
--- a/mpeglib/lib/mpegplay/mpegVideoBitWindow.h
+++ b/mpeglib/lib/mpegplay/mpegVideoBitWindow.h
@@ -53,10 +53,10 @@ class MpegVideoBitWindow {
inline unsigned int showBits(int bits) {
- unsigned int mask=nBitMask[bits];
+ unsigned int tqmask=nBitMask[bits];
int shift=32-(bits);
int bO;
- shift=(curBits & mask)>>shift;
+ shift=(curBits & tqmask)>>shift;
bO = bit_offset + bits;
if (bO > 32) {
return (shift | (*(buffer+1)>>(64-bO)));
diff --git a/mpeglib/lib/mpegplay/mpegVideoStream.cpp b/mpeglib/lib/mpegplay/mpegVideoStream.cpp
index 5e16b116..8ce1defd 100644
--- a/mpeglib/lib/mpegplay/mpegVideoStream.cpp
+++ b/mpeglib/lib/mpegplay/mpegVideoStream.cpp
@@ -48,7 +48,7 @@ int MpegVideoStream::firstInitialize(MpegVideoHeader* mpegHeader) {
fill_videoBuffer(mpegSystemHeader);
lHasStream=true;
}
- // now find SEQ_START_CODE
+ // now find SETQ_START_CODE
hasBytes(4);
mpegVideoBitWindow->flushByteOffset();
@@ -70,8 +70,8 @@ int MpegVideoStream::firstInitialize(MpegVideoHeader* mpegHeader) {
int MpegVideoStream::isStartCode(unsigned int data) {
switch(data) {
- case SEQ_END_CODE:
- case SEQ_START_CODE:
+ case SETQ_END_CODE:
+ case SETQ_START_CODE:
case GOP_START_CODE:
case PICTURE_START_CODE:
case SLICE_MIN_START_CODE:
@@ -125,7 +125,7 @@ int MpegVideoStream::nextPIC() {
unsigned int data=showBits(32);
if ( (data != PICTURE_START_CODE) &&
(data != GOP_START_CODE) &&
- (data != SEQ_START_CODE) ) {
+ (data != SETQ_START_CODE) ) {
flushBits(8);
return false;
}
diff --git a/mpeglib/lib/mpegplay/pesSystemStream.cpp b/mpeglib/lib/mpegplay/pesSystemStream.cpp
index 10787f21..b9915fc2 100644
--- a/mpeglib/lib/mpegplay/pesSystemStream.cpp
+++ b/mpeglib/lib/mpegplay/pesSystemStream.cpp
@@ -192,7 +192,7 @@ int PESSystemStream::processMPEG2PacketHeader(MpegSystemHeader* mpegHeader){
//LIVID
u_char original_or_copy : 1;
u_char copyright : 1;
- u_char data_alignment_indicator : 1;
+ u_char data_tqalignment_indicator : 1;
u_char pes_priority : 1;
u_char pes_scrambling_control : 2;
u_char start_code_prefix : 2; // 0x02
diff --git a/mpeglib/lib/mpegplay/picture.cpp b/mpeglib/lib/mpegplay/picture.cpp
index 6d8c1efe..b63f4989 100644
--- a/mpeglib/lib/mpegplay/picture.cpp
+++ b/mpeglib/lib/mpegplay/picture.cpp
@@ -63,7 +63,7 @@ int Picture::processPicture(MpegVideoStream* mpegVideoStream) {
stamp=mpegVideoStream->getCurrentTimeStamp();
stamp->copyTo(startOfPicStamp);
- // now invalidate the PTSFlag
+ // now tqinvalidate the PTSFlag
stamp->setPTSFlag(false);
diff --git a/mpeglib/lib/mpegplay/recon.cpp b/mpeglib/lib/mpegplay/recon.cpp
index 6116157a..81350345 100644
--- a/mpeglib/lib/mpegplay/recon.cpp
+++ b/mpeglib/lib/mpegplay/recon.cpp
@@ -298,7 +298,7 @@ int Recon::ReconPMBlock(int bnum,
} else {
if (right_for & 0x1) {
- /* No alignment, used byte copy */
+ /* No tqalignment, used byte copy */
copyFunctions->copy8_byte(rindex1,index,row_size);
@@ -498,7 +498,7 @@ int Recon::ReconBMBlock(int bnum,
copyFunctions->copy8_src2linear_crop(rindex1,dct_start,index,row_size);
} else {
if (right_back & 0x1) {
- /* No alignment, use byte copy */
+ /* No tqalignment, use byte copy */
copyFunctions->copy8_byte(rindex1,index,row_size);
diff --git a/mpeglib/lib/mpegplay/slice.h b/mpeglib/lib/mpegplay/slice.h
index 10689d34..13556155 100644
--- a/mpeglib/lib/mpegplay/slice.h
+++ b/mpeglib/lib/mpegplay/slice.h
@@ -38,7 +38,7 @@ class Slice {
/* Slice structure. */
- unsigned int vert_pos; /* Vertical position of slice. */
+ unsigned int vert_pos; /*Qt::Vertical position of slice. */
unsigned int quant_scale; /* Quantization scale. */
MpegExtension* mpegExtension; /* Extra bit slice info. */
diff --git a/mpeglib/lib/mpegplay/startCodes.h b/mpeglib/lib/mpegplay/startCodes.h
index c305a39f..94c2a56e 100644
--- a/mpeglib/lib/mpegplay/startCodes.h
+++ b/mpeglib/lib/mpegplay/startCodes.h
@@ -29,8 +29,8 @@
/* Start codes. */
-#define SEQ_END_CODE 0x000001b7
-#define SEQ_START_CODE 0x000001b3
+#define SETQ_END_CODE 0x000001b7
+#define SETQ_START_CODE 0x000001b3
#define GOP_START_CODE 0x000001b8
#define PICTURE_START_CODE 0x00000100
#define SLICE_MIN_START_CODE 0x00000101
@@ -42,7 +42,7 @@
//extension start code ids
#define SEQUENCE_EXTENSION_ID 1
#define SEQUENCE_DISPLAY_EXTENSION_ID 2
-#define QUANT_MATRIX_EXTENSION_ID 3
+#define TQUANT_MATRIX_EXTENSION_ID 3
#define COPYRIGHT_EXTENSION_ID 4
#define SEQUENCE_SCALABLE_EXTENSION_ID 5
#define PICTURE_DISPLAY_EXTENSION_ID 7
diff --git a/mpeglib/lib/mpegplay/videoDecoder.h b/mpeglib/lib/mpegplay/videoDecoder.h
index cba45a29..695b424d 100644
--- a/mpeglib/lib/mpegplay/videoDecoder.h
+++ b/mpeglib/lib/mpegplay/videoDecoder.h
@@ -53,7 +53,7 @@
/* Number of macroblocks to process in one call to mpegVidRsrc. */
-#define MB_QUANTUM 100
+#define MB_TQUANTUM 100
/* Video stream structure. */
diff --git a/mpeglib/lib/mpegplay/mpegExtension.cpp b/mpeglib/lib/mpegplay/mpegExtension.cpp
index 657fe683..3fc89215 100644
--- a/mpeglib/lib/mpegplay/mpegExtension.cpp
+++ b/mpeglib/lib/mpegplay/mpegExtension.cpp
@@ -89,7 +89,7 @@ int MpegExtension::processExtra_bit_info(MpegVideoStream* mpegVideoStream) {
-int MpegExtension::next_bits(int num,unsigned int mask,
+int MpegExtension::next_bits(int num,unsigned int tqmask,
MpegVideoStream* input) {
unsigned int data;
@@ -97,11 +97,11 @@ int MpegExtension::next_bits(int num,unsigned int mask,
data=input->showBits(num);
/* Compare bit stream and mask. Set return value toTRUE if equal, FALSE if
differs.
*/
- if (mask == data) {
+ if (tqmask == data) {
return true;
}
return false;
@@ -97,11 +97,11 @@ int MpegExtension::next_bits(int num,unsigned int mask,
data=input->showBits(num);
- /* Compare bit stream and mask. Set return value toTRUE if equal, FALSE if
+ /* Compare bit stream and tqmask. Set return value toTRUE if equal, FALSE if
differs.
*/
diff --git a/mpeglib/lib/mpegplay/videoDecoder.cpp b/mpeglib/lib/mpegplay/videoDecoder.cpp
index b1971795..b7144291 100644
--- a/mpeglib/lib/mpegplay/videoDecoder.cpp
+++ b/mpeglib/lib/mpegplay/videoDecoder.cpp
@@ -69,7 +69,7 @@ VideoDecoder::~VideoDecoder() {
*
* mpegVidRsrc --
*
* Parses bit stream until MB_QUANTUM number of
* macroblocks have been decoded or current slice or
* picture ends, whichever comes first. If the start
* of a frame is encountered, the frame is time stamped
@@ -121,7 +121,7 @@ int VideoDecoder::mpegVidRsrc(PictureArray* pictureArray) {
mpegVideoStream->flushBits(32);
packet->read_sys(data,vid_stream->bufferReader);
*/
- case SEQ_END_CODE:
+ case SETQ_END_CODE:
case ISO_11172_END_CODE: /* handle ISO_11172_END_CODE too */
/* Display last frame. */
@@ -148,11 +148,11 @@ int VideoDecoder::mpegVidRsrc(PictureArray* pictureArray) {
mpegVideoStream->next_start_code();
break;
- case SEQ_START_CODE:
+ case SETQ_START_CODE:
/* Sequence start code. Parse sequence header. */
if (ParseSeqHead() == false) {
- printf("SEQ_START_CODE 1-error\n");
+ printf("SETQ_START_CODE 1-error\n");
goto error;
}
goto done;
@@ -204,8 +204,8 @@ int VideoDecoder::mpegVidRsrc(PictureArray* pictureArray) {
break;
}
- /* Parse next MB_QUANTUM macroblocks. */
- for (i = 0; i < MB_QUANTUM; i++) {
+ /* Parse next MB_TQUANTUM macroblocks. */
+ for (i = 0; i < MB_TQUANTUM; i++) {
/* Check to see if actually a startcode and not a macroblock. */
data=mpegVideoStream->showBits(23);
@@ -232,7 +232,7 @@ int VideoDecoder::mpegVidRsrc(PictureArray* pictureArray) {
}
}
data=mpegVideoStream->showBits(23);
/* Check if we just finished a picture on the MB_QUANTUM macroblock */
if (data == 0x0) {
mpegVideoStream->next_start_code();
@@ -69,7 +69,7 @@ VideoDecoder::~VideoDecoder() {
* mpegVidRsrc --
*
- * Parses bit stream until MB_QUANTUM number of
+ * Parses bit stream until MB_TQUANTUM number of
* macroblocks have been decoded or current slice or
* picture ends, whichever comes first. If the start
@@ -232,7 +232,7 @@ int VideoDecoder::mpegVidRsrc(PictureArray* pictureArray) {
}
data=mpegVideoStream->showBits(23);
- /* Check if we just finished a picture on the MB_QUANTUM macroblock */
+ /* Check if we just finished a picture on the MB_TQUANTUM macroblock */
if (data == 0x0) {
mpegVideoStream->next_start_code();